Main View
==========

.. automodule:: rabbitChat.apps.main.views


IndexHandler
-------------

.. autoclass:: IndexHandler
   :members:
   :undoc-members:
   :private-members:
   :special-members:
   :inherited-members:
   :member-order: bysource
   



ChatWebsocketHandler
--------------------

.. autoclass:: ChatWebsocketHandler
   :members:
   :undoc-members:
   :private-members:
   :special-members:
   :inherited-members:
   :member-order: bysource
                       





